# `narwhals.Series.str`

::: narwhals.series.SeriesStringNamespace
    handler: python
    options:
      members:
        - contains
        - ends_with
        - head
        - slice
        - starts_with
        - tail
      show_source: false
      show_bases: false
